# Ideas for OFF
Preliminary collection of ideas relevant to OFF, sorted by topic

## Input
### Interactive Simulation Assembly
The interactive simulation assembly could be moved to a html based dashboard, such as
[Plotly | Dash](https://dash.gallery/Portal/) (parially commercial), tutorial to use
[Dash](https://realpython.com/python-dash/). Otherwise there is also [Binder](https://mybinder.org)
(partially commercial) which converts a Git into a website. Maybe also [Django](https://www.djangoproject.com/start/overview/).

### Database
The IEA Wind Task 37 has defined some standards for .yaml files in their [GitHub](https://github.com/IEAWindTask37/windIO).
These standards aim to allow for interchangeable components in an optimization framework. They also allow to check new
data for incompleteness.

The OFF requirements are a bit different from what the Task has defined. It would make sense to find these differences
and to set up a similar, hopefully compatible, framework for the database:
- OFF requires (profits from) additional DOF for the turbine data - for instance CT based on blade pitch and tip-speed-ratio
instead of wind speed, assuming that the turbine does not run greedy control all the time.
- Wind field input has to facilitate dynamic choices
- ...?

### Network based input
Currently the framework is set up to simulate based on prescribed inputs. In the future this could be replaced by a
network link (UDP / TCP) to receive data from a real wind farm or a *real wind farm*.

### SCADAR data input
- Consensus algorithm for wind direction https://doi.org/10.5194/wes-4-355-2019
- Wind speed estimator
  - I\&I
  - Power inverse

## Simulation

### Wakes
dynamic surrogate wakes
- Dynamic yawing Curl model (Tony)
- Wake model Kheirabadi (A low-fidelity dynamic wind farm model for simulating time-varying wind conditions and floating platform motion)
- Orientation for the TWF slice

### Ambient flow Field
- [Shepard interpolation](https://en.wikipedia.org/wiki/Inverse_distance_weighting)
- Spacio temporal Gauss weighting

### Wake Solvers
Julia & C based wake solvers
#### C / C++ wrappers
[SWIG](https://swig.org) was recommended - links C, C++ code to Javascript, Perl, PHP, Python, Tcl, Ruby, C#, D, Go language, Java including Android, Lua, OCaml, Octave, Scilab and R.

### Turbine
- Turbine model: Power calculated by cos(yaw)^p
- Turbine model: Power calculated by Howland model

## Logging
### Report
Generate a LaTeX based report based on the logging files and results.

## Testing
Actually implement it
## Visualization
### Show case simulations
Live inputs which show impacts in real time. Changing the yaw angle for instance or changing the wind direction etc.
This would be great if linked with a great visualization engine such as [Unreal Engine 5](https://www.unrealengine.com).

### Voronoi TWF pattern
Use new interface of FLORIS to generate a "window" into the TWF, window
generated by a Voronoi pattern.

## Use cases
### API
Create something like the FLORIS interface for OFF. Functionality would be to
run a simulation automated, change parameters, reset to  certain point, etc.

### Pre-Simulation for LES
Enhance AMR Wind GUI with OFF pre-simulation

## Documentation
